@@ -95,18 +95,9 @@ try
 
     try
     {
-        Arg::initialize('t', "+abcd:e:f:hvt",
-                lo, lo + 6,
-                argc, argv).deleter();          // call deleter() to delete
-                                                // s_arg (and the memory
-                                                // allocated by the Arg
-                                                // object to which s_arg
-                                                // points.
+        Arg::initialize('t', "+abcd:e:f::hvt", lo, lo + 6, argc, argv);
 
-        Arg &arg = Arg::instance();
-
-
-    return 0;
+        Arg &arg = Arg::instance();   // just to check ::instance()
 
         cout << "dashed options start at index " << arg.beyondDashes() << endl;
 
