@@ -8,7 +8,7 @@ Arg &Arg::initialize(int accept, char const *optstring,
     if (s_arg)
         throw Exception{} << s_alreadyInitialized;
 
-    s_arg = new Arg(accept, optstring, begin, end, argc, argv);
+    s_arg.reset(new Arg(accept, optstring, begin, end, argc, argv));
 
     return *s_arg;
 }
