@@ -2,5 +2,5 @@
 
 EVP_CIPHER_CTX *DecryptBuf::cipherCtx()
 {
-    return d_ctx;
+    return 0;
 }
