@@ -24,8 +24,6 @@ void Milter::initialize(string const &name, Milter &milter,
     s_name = name;
     s_mp = &milter;
 
-    s_callClose = callbacks & CLOSE;        // Milter has its own close
-                                            // function
     callbacks |= CLOSE;                     // always call mClose()
 
     for (size_t callback = 1; callback & ALL_CALLBACKS; callback <<= 1)
