@@ -1,4 +1,4 @@
 inline void OFoldStream::setTrailingBlanks(TrailingBlanks tb)
 {
-    OFoldStreambuf::setTrailingBlanks(tb);
+    OFoldBuf::setTrailingBlanks(tb);
 }
