@@ -2,6 +2,9 @@
 
 size_t ReadLineBuf::readLine()
 {
+    ofstream out{"/tmp/log", ios::app};
+    out << "called" << endl;
+
     char *buf = readline(d_prompt.c_str());     // readline(3)
 
     if (buf == 0)
